@@ -1,7 +1,6 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright © 2013 Zulip, Inc.
+# Copyright © 2014 Zulip, Inc.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -22,7 +21,6 @@
 # THE SOFTWARE.
 
 
-
 # Change these values to configure authentication for your codebase account
 # Note that this is the Codebase API Username, found in the Settings page
 # for your account
@@ -50,8 +48,8 @@ ZULIP_TICKETS_STREAM_NAME = "tickets"
 # path, but if not, set a custom path below
 ZULIP_API_PATH = None
 
-# If you're using Zulip Enterprise, set this to your Zulip Enterprise server
-ZULIP_SITE = "https://api.zulip.com"
+# Set this to your Zulip API server URI
+ZULIP_SITE = "https://zulip.example.com"
 
 # If you wish to log to a file rather than stdout/stderr,
 # please fill this out your desired path
