@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 # Zulip hook for Mercurial changeset pushes.
-# Copyright © 2012-2013 Zulip, Inc.
+# Copyright Â© 2012-2014 Zulip, Inc.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,13 +24,18 @@
 #
 #
 # This hook is called when changesets are pushed to the master repository (ie
-# `hg push`). See https://zulip.com/integrations for installation instructions.
+# `hg push`). See https://zulipchat.com/integrations for installation instructions.
+from __future__ import absolute_import
 
 import zulip
+from six.moves import range
+from typing import Any, Optional, Text
+from mercurial import ui, repo
 
 VERSION = "0.9"
 
 def format_summary_line(web_url, user, base, tip, branch, node):
+    # type: (str, str, int, int, str, Text) -> Text
     """
     Format the first line of the message, which contains summary
     information about the changeset and links to the changelog if a
@@ -56,6 +61,7 @@ def format_summary_line(web_url, user, base, tip, branch, node):
         node=node[:12])
 
 def format_commit_lines(web_url, repo, base, tip):
+    # type: (str, repo, int, int) -> str
     """
     Format the per-commit information for the message, including the one-line
     commit summary and a link to the diff if a web URL has been configured:
@@ -81,6 +87,7 @@ def format_commit_lines(web_url, repo, base, tip):
     return "\n".join(summary for summary in commit_summaries)
 
 def send_zulip(email, api_key, site, stream, subject, content):
+    # type: (str, str, str, str, str, Text) -> None
     """
     Send a message to Zulip using the provided credentials, which should be for
     a bot in most cases.
@@ -99,6 +106,7 @@ def send_zulip(email, api_key, site, stream, subject, content):
     client.send_message(message_data)
 
 def get_config(ui, item):
+    # type: (ui, str) -> Optional[str]
     try:
         # configlist returns everything in lists.
         return ui.configlist('zulip', item)[0]
@@ -106,6 +114,7 @@ def get_config(ui, item):
         return None
 
 def hook(ui, repo, **kwargs):
+    # type: (ui, repo, **Text) -> None
     """
     Invoked by configuring a [hook] entry in .hg/hgrc.
     """
