@@ -1,7 +1,6 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright © 2013 Zulip, Inc.
+# Copyright © 2014 Zulip, Inc.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -53,5 +52,5 @@ def commit_notice_destination(path, commit):
 ## path, but if not, set a custom path below
 ZULIP_API_PATH = None
 
-# If you're using Zulip Enterprise, set this to your Zulip Enterprise server
-ZULIP_SITE = "https://api.zulip.com"
+# Set this to your Zulip server's API URI
+ZULIP_SITE = "https://zulip.example.com"
