@@ -42,6 +42,9 @@ sys.path.insert(0, os.path.dirname(__file__))
 import zulip_trac_config as config
 VERSION = "0.9"
 
+if False:
+    from typing import Any, Dict
+
 if config.ZULIP_API_PATH is not None:
     sys.path.append(config.ZULIP_API_PATH)
 
@@ -53,31 +56,37 @@ client = zulip.Client(
     client="ZulipTrac/" + VERSION)
 
 def markdown_ticket_url(ticket, heading="ticket"):
+    # type: (Any, str) -> str
     return "[%s #%s](%s/%s)" % (heading, ticket.id, config.TRAC_BASE_TICKET_URL, ticket.id)
 
 def markdown_block(desc):
+    # type: (str) -> str
     return "\n\n>" + "\n> ".join(desc.split("\n")) + "\n"
 
 def truncate(string, length):
+    # type: (str, int) -> str
     if len(string) <= length:
         return string
     return string[:length - 3] + "..."
 
 def trac_subject(ticket):
+    # type: (Any) -> str
     return truncate("#%s: %s" % (ticket.id, ticket.values.get("summary")), 60)
 
 def send_update(ticket, content):
+    # type: (Any, str) -> None
     client.send_message({
-            "type": "stream",
-            "to": config.STREAM_FOR_NOTIFICATIONS,
-            "content": content,
-            "subject": trac_subject(ticket)
-            })
+        "type": "stream",
+        "to": config.STREAM_FOR_NOTIFICATIONS,
+        "content": content,
+        "subject": trac_subject(ticket)
+    })
 
 class ZulipPlugin(Component):
     implements(ITicketChangeListener)
 
     def ticket_created(self, ticket):
+        # type: (Any) -> None
         """Called when a ticket is created."""
         content = "%s created %s in component **%s**, priority **%s**:\n" % \
             (ticket.values.get("reporter"), markdown_ticket_url(ticket),
@@ -90,6 +99,7 @@ class ZulipPlugin(Component):
         send_update(ticket, content)
 
     def ticket_changed(self, ticket, comment, author, old_values):
+        # type: (Any, str, str, Dict[str, Any]) -> None
         """Called when a ticket is modified.
 
         `old_values` is a dictionary containing the previous values of the
@@ -107,8 +117,8 @@ class ZulipPlugin(Component):
         field_changes = []
         for key in old_values.keys():
             if key == "description":
-                content += '- Changed %s from %s to %s' % (key, markdown_block(old_values.get(key)),
-                                                           markdown_block(ticket.values.get(key)))
+                content += '- Changed %s from %s\n\nto %s' % (key, markdown_block(old_values.get(key)),
+                                                              markdown_block(ticket.values.get(key)))
             elif old_values.get(key) == "":
                 field_changes.append('%s: => **%s**' % (key, ticket.values.get(key)))
             elif ticket.values.get(key) == "":
@@ -121,6 +131,7 @@ class ZulipPlugin(Component):
         send_update(ticket, content)
 
     def ticket_deleted(self, ticket):
+        # type: (Any) -> None
         """Called when a ticket is deleted."""
         content = "%s was deleted." % markdown_ticket_url(ticket, heading="Ticket")
         send_update(ticket, content)
